@@ -1,4 +1,4 @@
-__version__ = '0.3.5'
+__version__ = '0.3.6'
 
 import os
 import re
@@ -41,9 +41,12 @@ def get_files(dir, ext):
     return result
 
 def fix_var_name(var_str, verbose=False):
-    if not var_str[0].isalnum():
+    # variable must start with letter, number, or underscore
+    valid = var_str[0].isalnum() or var_str[0] == '_'
+    if not valid:
         var_str = 'x' + var_str
-    fixed_name = re.sub('\W|^(?=\d)','_', var_str)
+    # replace disallowed characters with an underscore
+    fixed_name = re.sub('\W|^(?=\d)', '_', var_str)
     if fixed_name != var_str and verbose:
         print('info: {0} is not a valid Python variable name, changing to {1}'.format(var_str, fixed_name))
     return fixed_name
